ajdmom.mdl\_1fsv.euler
======================

.. automodule:: ajdmom.mdl_1fsv.euler

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      r1FSV
   
   

   
   
   

   
   
   



